@@ -17,7 +17,7 @@ from typing import Callable, Dict, List, Optional, Tuple, TypeVar, Union, Any
 from . import np
 from .unit import read_resistance
 from lxml import etree, objectify # type: ignore
-from .pcbnew_transition import KICAD_VERSION, isV6, pcbnew # type: ignore
+from .pcbnew_transition import KICAD_VERSION, isV6, isV7, pcbnew # type: ignore
 
 T = TypeVar("T")
 Numeric = Union[int, float]
@@ -30,6 +30,8 @@ PKG_BASE = os.path.dirname(__file__)
 
 etree.register_namespace("xlink", "http://www.w3.org/1999/xlink")
 
+LEGACY_KICAD = not isV6() and not isV7()
+
 default_style = {
     "copper": "#417e5a",
     "board": "#4ca06c",
@@ -96,7 +98,10 @@ class SvgPathItem:
     def is_same(p1: Point, p2: Point) -> bool:
         dx = p1[0] - p2[0]
         dy = p1[1] - p2[1]
-        return math.sqrt(dx*dx+dy*dy) < 100
+        pseudo_distance = dx*dx + dy*dy
+        if isV7():
+            return pseudo_distance < 0.01 ** 2
+        return pseudo_distance < 100 ** 2
 
     def format(self, first: bool) -> str:
         ret = ""
@@ -521,7 +526,7 @@ def remove_inkscape_annotation(tree: etree.Element) -> None:
 @dataclass
 class Hole:
     position: Tuple[int, int]
-    orientation: int
+    orientation: pcbnew.EDA_ANGLE
     drillsize: Tuple[int, int]
 
     def get_svg_path_d(self, ki2svg: Callable[[int], float]) -> str:
@@ -570,14 +575,14 @@ def collect_holes(board: pcbnew.BOARD) -> List[Hole]:
                 orientation=pad.GetOrientation(),
                 drillsize=(drs.x, drs.y)
             ))
-    via_type = 'VIA' if not isV6(KICAD_VERSION) else 'PCB_VIA'
+    via_type = 'VIA' if LEGACY_KICAD else 'PCB_VIA'
     for track in board.GetTracks():
         if track.GetClass() != via_type:
             continue
         pos = track.GetPosition()
         holes.append(Hole(
             position=(pos[0], pos[1]),
-            orientation=0,
+            orientation=pcbnew.EDA_ANGLE(0, pcbnew.DEGREES_T),
             drillsize=(track.GetDrillValue(), track.GetDrillValue())
         ))
     return holes
@@ -676,7 +681,7 @@ class PlotSubstrate(PlotInterface):
             el = etree.SubElement(layer, "path")
             el.attrib["d"] = hole.get_svg_path_d(self._plotter.ki2svg)
             el.attrib["transform"] = "translate({} {}) rotate({})".format(
-                position[0], position[1], -hole.orientation / 10)
+                position[0], position[1], -hole.orientation.AsDegrees())
 
     def _process_baselayer(self, name: str, source_filename: str) -> None:
         clipPath = self._plotter.get_def_slot(tag_name="clipPath", id="cut-off")
@@ -747,7 +752,7 @@ class PlotSubstrate(PlotInterface):
                 el.attrib["stroke-width"] = str(stroke)
                 el.attrib["points"] = points
                 el.attrib["transform"] = "translate({} {}) rotate({})".format(
-                    position[0], position[1], -hole.orientation / 10)
+                    position[0], position[1], -hole.orientation.AsDegrees())
 
 @dataclass
 class PlacedComponentInfo:
@@ -1019,8 +1024,15 @@ class PcbPlotter():
 
         self.yield_warning: Callable[[str, str], None] = lambda tag, msg: None # Handle warnings
 
-        self.ki2svg = self._ki2svg_v6 if isV6(KICAD_VERSION) else self._ki2svg_v5
-        self.svg2ki = self._svg2ki_v6 if isV6(KICAD_VERSION) else self._svg2ki_v5
+        if isV7():
+            self.ki2svg = self._ki2svg_v7
+            self.svg2ki = self._svg2ki_v7
+        elif isV6():
+            self.ki2svg = self._ki2svg_v6
+            self.svg2ki = self._svg2ki_v6
+        else:
+            self.ki2svg = self._ki2svg_v5
+            self.svg2ki = self._svg2ki_v5
 
     @property
     def svg_precision(self) -> int:
@@ -1074,7 +1086,7 @@ class PcbPlotter():
             value = footprint.GetValue().strip()
             ref = footprint.GetReference().strip()
             center = footprint.GetPosition()
-            orient = math.radians(footprint.GetOrientation() / 10)
+            orient = math.radians(footprint.GetOrientation().AsDegrees())
             pos = (center.x, center.y, orient)
             callback(lib, name, ref, value, pos)
 
@@ -1198,8 +1210,10 @@ class PcbPlotter():
                 # Method does not exist in older versions of KiCad
                 pass
             popt.SetTextMode(pcbnew.PLOT_TEXT_MODE_STROKE)
-            if isV6(KICAD_VERSION):
+            if isV6():
                 popt.SetSvgPrecision(self.svg_precision, False)
+            elif isV7():
+                popt.SetSvgPrecision(self.svg_precision)
             for action in to_plot:
                 if len(action.layers) == 0:
                     continue
@@ -1238,6 +1252,12 @@ class PcbPlotter():
     def _svg2ki_v5(self, x: float) -> int:
         return dmil2ki(x)
 
+    def _svg2ki_v7(self, x: float) -> int:
+        return int(pcbnew.FromMM(x))
+
+    def _ki2svg_v7(self, x: int) -> float:
+        return float(pcbnew.ToMM(x))
+
     def _shrink_svg(self, svg: etree.ElementTree, margin: tuple, compute_bbox: bool=False) -> None:
         """
         Shrink the SVG canvas to the size of the drawing. Add margin in
