@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2020-2022 Salvador E. Tropea
-# Copyright (c) 2020-2022 Instituto Nacional de Tecnología Industrial
+# Copyright (c) 2020-2023 Salvador E. Tropea
+# Copyright (c) 2020-2023 Instituto Nacional de Tecnología Industrial
 # License: GPL-3.0
 # Project: KiBot (formerly KiPlot)
 import os
 from tempfile import mkdtemp
-from shutil import rmtree, copy2
+from shutil import copy2
 from .gs import GS
-from .kiplot import add_extra_options, exec_with_retry
 from .out_base import VariantOptions
 from .kicad.config import KiConf
 from .macros import macros, document, output_class  # noqa: F401
@@ -34,11 +33,15 @@ class Any_SCH_PrintOptions(VariantOptions):
     def __init__(self):
         with document:
             self.monochrome = False
-            """ Generate a monochromatic PDF """
+            """ Generate a monochromatic output """
             self.frame = True
             """ *Include the frame and title block """
             self.all_pages = True
             """ Generate with all hierarchical sheets """
+            self.color_theme = ''
+            """ Color theme used, this must exist in the KiCad config (KiCad 6) """
+            self.background_color = False
+            """ Use the background color from the `color_theme` (KiCad 6) """
         super().__init__()
         self.add_to_doc('variant', "Not fitted components are crossed")
         self._expand_id = 'schematic'
@@ -50,36 +53,31 @@ class Any_SCH_PrintOptions(VariantOptions):
 
     def run(self, name):
         super().run(name)
-        output_dir = os.path.dirname(name)
-        our_name = self._expand_ext+'_sch_print'
         command = self.ensure_tool('KiAuto')
         if self._comps:
             # Save it to a temporal dir
-            sch_dir = mkdtemp(prefix='tmp-kibot-'+our_name+'-')
+            sch_dir = mkdtemp(prefix='tmp-kibot-'+self._expand_ext+'_sch_print-')
             copy_project(sch_dir)
             fname = GS.sch.save_variant(sch_dir)
             sch_file = os.path.join(sch_dir, fname)
+            self._files_to_remove.append(sch_dir)
         else:
-            sch_dir = None
             sch_file = GS.sch_file
-        cmd = [command, 'export', '--file_format', self._expand_ext, '-o', name]
+        fmt = 'hpgl' if self._expand_ext == 'plt' else self._expand_ext
+        cmd = [command, 'export', '--file_format', fmt, '-o', name]
         if self.monochrome:
             cmd.append('--monochrome')
         if not self.frame:
             cmd.append('--no_frame')
         if self.all_pages:
             cmd.append('--all_pages')
-        cmd.extend([sch_file, output_dir])
-        cmd, video_remove = add_extra_options(cmd)
-        ret = exec_with_retry(cmd)
-        if ret:
-            logger.error(command+' returned %d', ret)
-            exit(self._exit_error)
-        # Remove the temporal dir if needed
-        if sch_dir:
-            logger.debug('Removing temporal variant dir `{}`'.format(sch_dir))
-            rmtree(sch_dir)
-        if video_remove:
-            video_name = os.path.join(output_dir, 'export_eeschema_screencast.ogv')
-            if os.path.isfile(video_name):
-                os.remove(video_name)
+        if self.color_theme:
+            cmd.extend(['--color_theme', self.color_theme])
+        if self.background_color:
+            cmd.append('--background_color')
+        if hasattr(self, '_origin'):
+            cmd.extend(['--hpgl_origin', str(self._origin)])
+        if hasattr(self, 'pen_size'):
+            cmd.extend(['--hpgl_pen_size', str(self.pen_size)])
+        cmd.extend([sch_file, os.path.dirname(name)])
+        self.exec_with_retry(self.add_extra_options(cmd), self._exit_error)
