@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2020-2022 Salvador E. Tropea
-# Copyright (c) 2020-2022 Instituto Nacional de Tecnología Industrial
+# Copyright (c) 2020-2023 Salvador E. Tropea
+# Copyright (c) 2020-2023 Instituto Nacional de Tecnología Industrial
 # License: MIT
 # Project: KiBot (formerly KiPlot)
 """
@@ -22,7 +22,7 @@ from copy import deepcopy
 import os
 import re
 from .gs import GS
-from .misc import W_BADFIELD, W_NEEDSPCB, DISTRIBUTORS, IFILT_EXPAND_TEXT_VARS, W_NOPART, W_MISSREF
+from .misc import W_BADFIELD, W_NEEDSPCB, DISTRIBUTORS, W_NOPART, W_MISSREF, DISTRIBUTORS_STUBS, DISTRIBUTORS_STUBS_SEPS
 from .optionable import Optionable, BaseOptions
 from .registrable import RegOutput
 from .error import KiPlotConfigurationError
@@ -137,7 +137,8 @@ class BoMColumns(Optionable):
         self._unkown_is_error = True
         with document:
             self.field = ''
-            """ *Name of the field to use for this column """
+            """ *Name of the field to use for this column.
+                Use `_field_lcsc_part` to get the value defined in the global options """
             self.name = ''
             """ *Name to display in the header. The field is used when empty """
             self.join = BoMJoinField
@@ -153,9 +154,10 @@ class BoMColumns(Optionable):
         super().config(parent)
         if not self.field:
             raise KiPlotConfigurationError("Missing or empty `field` in columns list ({})".format(str(self._tree)))
+        self.field = self.solve_field_name(self.field)
+        field = self.field.lower()
         # Ensure this is None or a list
         # Also arrange it as field, cols...
-        field = self.field.lower()
         if isinstance(self.join, type):
             self.join = None
         elif isinstance(self.join, str):
@@ -184,6 +186,8 @@ class BoMLinkable(Optionable):
             """ *Column with links to the datasheet """
             self.digikey_link = Optionable
             """ [string|list(string)=''] Column/s containing Digi-Key part numbers, will be linked to web page """
+            self.mouser_link = Optionable
+            """ [string|list(string)=''] Column/s containing Mouser part numbers, will be linked to web page """
             self.generate_dnf = True
             """ *Generate a separated section for DNF (Do Not Fit) components """
             self.hide_pcb_info = False
@@ -201,11 +205,9 @@ class BoMLinkable(Optionable):
 
     def config(self, parent):
         super().config(parent)
-        # digikey_link
-        if isinstance(self.digikey_link, type):
-            self.digikey_link = []
-        elif isinstance(self.digikey_link, list):
-            self.digikey_link = [c.lower() for c in self.digikey_link]
+        # *_link
+        self.digikey_link = self.force_list(self.digikey_link, comma_sep=False, lower_case=True)
+        self.mouser_link = self.force_list(self.mouser_link, comma_sep=False, lower_case=True)
         # Logo
         if isinstance(self.logo, type):
             self.logo = ''
@@ -247,7 +249,8 @@ class BoMCSV(Optionable):
         super().__init__()
         with document:
             self.separator = ','
-            """ *CSV Separator. TXT and TSV always use tab as delimiter """
+            """ *CSV Separator. TXT and TSV always use tab as delimiter.
+                Only one character can be specified """
             self.hide_header = False
             """ Hide the header line (names of the columns) """
             self.hide_pcb_info = False
@@ -257,6 +260,43 @@ class BoMCSV(Optionable):
             self.quote_all = False
             """ *Enclose all values using double quotes """
 
+    def config(self, parent):
+        super().config(parent)
+        if self.separator:
+            self.separator = self.separator.replace(r'\t', '\t')
+            self.separator = self.separator.replace(r'\n', '\n')
+            self.separator = self.separator.replace(r'\r', '\r')
+            self.separator = self.separator.replace(r'\\', '\\')
+        if len(self.separator) != 1:
+            raise KiPlotConfigurationError('The CSV separator must be one character (`{}`)'.format(self.separator))
+
+
+class BoMTXT(Optionable):
+    """ HRTXT options """
+    def __init__(self):
+        super().__init__()
+        with document:
+            self.separator = 'I'
+            """ *Column Separator """
+            self.header_sep = '-'
+            """ Separator between the header and the data """
+            self.justify = 'left'
+            """ [left,right,center] Text justification """
+            self.hide_header = False
+            """ Hide the header line (names of the columns) """
+            self.hide_pcb_info = False
+            """ Hide project information """
+            self.hide_stats_info = False
+            """ Hide statistics information """
+
+    def config(self, parent):
+        super().config(parent)
+        if self.separator:
+            self.separator = self.separator.replace(r'\t', '\t')
+            self.separator = self.separator.replace(r'\n', '\n')
+            self.separator = self.separator.replace(r'\r', '\r')
+            self.separator = self.separator.replace(r'\\', '\\')
+
 
 class BoMXLSX(BoMLinkable):
     """ XLSX options """
@@ -268,7 +308,8 @@ class BoMXLSX(BoMLinkable):
             self.style = 'modern-blue'
             """ Head style: modern-blue, modern-green, modern-red and classic """
             self.kicost = False
-            """ *Enable KiCost worksheet creation """
+            """ *Enable KiCost worksheet creation.
+                Note: an example of how to use it on CI/CD can be found [here](https://github.com/set-soft/kicost_ci_test) """
             self.kicost_api_enable = Optionable
             """ [string|list(string)=''] List of KiCost APIs to enable """
             self.kicost_api_disable = Optionable
@@ -277,7 +318,10 @@ class BoMXLSX(BoMLinkable):
             """ Used to add a column with the distributor's description. So you can check this is the right component """
             self.kicost_config = ''
             """ KiCost configuration file. It contains the keys for the different distributors APIs.
-                The regular KiCost config is used when empty """
+                The regular KiCost config is used when empty.
+                Important for CI/CD environments: avoid exposing your API secrets!
+                To understand how to achieve this, and also how to make use of the cache please visit the
+                [kicost_ci_test](https://github.com/set-soft/kicost_ci_test) repo """
             self.specs = False
             """ *Enable Specs worksheet creation. Contains specifications for the components.
                 Works with only some KiCost APIs """
@@ -400,8 +444,9 @@ class BoMOptions(BaseOptions):
             self.output = GS.def_global_output
             """ *filename for the output (%i=bom)"""
             self.format = ''
-            """ *[HTML,CSV,TXT,TSV,XML,XLSX] format for the BoM.
-                Defaults to CSV or a guess according to the options. """
+            """ *[HTML,CSV,TXT,TSV,XML,XLSX,HRTXT] format for the BoM.
+                Defaults to CSV or a guess according to the options.
+                HRTXT stands for Human Readable TeXT """
             # Equivalent to KiBoM INI:
             self.ignore_dnf = True
             """ *Exclude DNF (Do Not Fit) components """
@@ -427,6 +472,8 @@ class BoMOptions(BaseOptions):
             """ *[dict] Options for the XLSX format """
             self.csv = BoMCSV
             """ *[dict] Options for the CSV, TXT and TSV formats """
+            self.hrtxt = BoMTXT
+            """ *[dict] Options for the HRTXT formats """
             # * Filters
             self.pre_transform = Optionable
             """ [string|list(string)='_none'] Name of the filter to transform fields before applying other filters.
@@ -542,6 +589,9 @@ class BoMOptions(BaseOptions):
             # Same for XLSX
             if not isinstance(self.xlsx, type):
                 return 'xlsx'
+            # Same for HRTXT
+            if not isinstance(self.hrtxt, type):
+                return 'hrtxt'
             # Default to a simple and common format: CSV
             return 'csv'
         # Explicit selection
@@ -549,11 +599,8 @@ class BoMOptions(BaseOptions):
 
     def _normalize_variant(self):
         """ Replaces the name of the variant by an object handling it. """
-        if self.variant:
-            if not RegOutput.is_variant(self.variant):
-                raise KiPlotConfigurationError("Unknown variant name `{}`".format(self.variant))
-            self.variant = RegOutput.get_variant(self.variant)
-        else:
+        self.variant = RegOutput.check_variant(self.variant)
+        if self.variant is None:
             # If no variant is specified use the KiBoM variant class with basic functionality
             self.variant = KiBoM()
             self.variant.config_field = self.fit_field
@@ -628,7 +675,7 @@ class BoMOptions(BaseOptions):
         super().config(parent)
         self.format = self._guess_format()
         self._expand_id = 'bom'
-        self._expand_ext = self.format.lower()
+        self._expand_ext = 'txt' if self.format.lower() == 'hrtxt' else self.format.lower()
         # HTML options
         if self.format == 'html' and isinstance(self.html, type):
             # If no options get the defaults
@@ -639,6 +686,11 @@ class BoMOptions(BaseOptions):
             # If no options get the defaults
             self.csv = BoMCSV()
             self.csv.config(self)
+        # HRTXT options
+        if self.format == 'hrtxt' and isinstance(self.hrtxt, type):
+            # If no options get the defaults
+            self.hrtxt = BoMTXT()
+            self.hrtxt.config(self)
         # XLSX options
         if self.format == 'xlsx' and isinstance(self.xlsx, type):
             # If no options get the defaults
@@ -671,7 +723,7 @@ class BoMOptions(BaseOptions):
         if isinstance(self.component_aliases, type):
             self.component_aliases = DEFAULT_ALIASES
         # Filters
-        self.pre_transform = BaseFilter.solve_filter(self.pre_transform, 'pre_transform')
+        self.pre_transform = BaseFilter.solve_filter(self.pre_transform, 'pre_transform', is_transform=True)
         self.exclude_filter = BaseFilter.solve_filter(self.exclude_filter, 'exclude_filter')
         self.dnf_filter = BaseFilter.solve_filter(self.dnf_filter, 'dnf_filter')
         self.dnc_filter = BaseFilter.solve_filter(self.dnc_filter, 'dnc_filter')
@@ -867,7 +919,7 @@ class BoMOptions(BaseOptions):
         # Now expand the text variables, the user can disable it and insert a customized filter
         # in the variant or even before.
         if self.expand_text_vars:
-            comps = apply_pre_transform(comps, BaseFilter.solve_filter(IFILT_EXPAND_TEXT_VARS, 'KiCad 6 text vars',
+            comps = apply_pre_transform(comps, BaseFilter.solve_filter('_expand_text_vars', 'KiCad 6 text vars',
                                                                        is_transform=True))
         # We add the main project to the aggregate list so do_bom sees a complete list
         base_sch = Aggregate()
@@ -922,6 +974,8 @@ class BoM(BaseOutput):  # noqa: F821
         gb['type'] = 'bom'
         gb['dir'] = os.path.join('BoM', subd)
         ops = {'format': fmt}
+        if fmt == 'HRTXT':
+            ops['hrtxt'] = {'separator': '|'}
         if group_fields:
             ops['group_fields'] = group_fields
         if join_fields:
@@ -944,8 +998,6 @@ class BoM(BaseOutput):  # noqa: F821
         for tpl in templates:
             for out in tpl:
                 if out['type'] == 'bom':
-                    # Use the KiCost + rotate variant
-                    out['options']['variant'] = 'place_holder'
                     columns = out['options'].get('columns', None)
                     if columns:
                         # Rename MPN for something we have, or just remove it
@@ -980,12 +1032,12 @@ class BoM(BaseOutput):  # noqa: F821
         mpn_fields = fld_set.intersection(mpn_set)
         # Look for distributor part number
         dpn_set = set()
-        for stub in ['part#', '#', 'p#', 'pn', 'vendor#', 'vp#', 'vpn', 'num']:
+        for stub in DISTRIBUTORS_STUBS:
             for dist in DISTRIBUTORS:
                 dpn_set.add(dist+stub)
                 if stub != '#':
-                    dpn_set.add(dist+'_'+stub)
-                    dpn_set.add(dist+'-'+stub)
+                    for sep in DISTRIBUTORS_STUBS_SEPS:
+                        dpn_set.add(dist+sep+stub)
         dpn_fields = fld_set.intersection(dpn_set)
         # Collect the used distributors
         dists = set()
@@ -1007,7 +1059,7 @@ class BoM(BaseOutput):  # noqa: F821
         if join_fields:
             logger.debug(' - Fields to join with Value: {}'.format(join_fields))
         # Create a generic version
-        SIMP_FMT = ['HTML', 'CSV', 'TXT', 'TSV', 'XML']
+        SIMP_FMT = ['HTML', 'CSV', 'HRTXT', 'TSV', 'XML']
         XYRS_FMT = ['HTML']
         if GS.check_tool(name, 'XLSXWriter') is not None:
             SIMP_FMT.append('XLSX')
@@ -1034,7 +1086,9 @@ class BoM(BaseOutput):  # noqa: F821
                     grp.append(d+'#')
             gb = BoM.create_bom('XLSX', 'Costs', grp, join_fields, fld_names)
             gb['options']['xlsx'] = {'style': 'modern-green', 'kicost': True, 'specs': True}
-            gb['options']['variant'] = 'place_holder'
+            # KitSpace seems to be failing all the time
+            gb['options']['xlsx']['kicost_api_disable'] = 'KitSpace'
+            gb['options']['pre_transform'] = '_kicost_rename'
             # gb['options']['distributors'] = list(dists)
             outs.append(gb)
         # Add the list of layers to the templates
