@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2021-2022 Salvador E. Tropea
-# Copyright (c) 2021-2022 Instituto Nacional de Tecnología Industrial
+# Copyright (c) 2021-2023 Salvador E. Tropea
+# Copyright (c) 2021-2023 Instituto Nacional de Tecnología Industrial
 # License: GPL-3.0
 # Project: KiBot (formerly KiPlot)
 """
@@ -24,8 +24,8 @@ from zipfile import ZipFile, ZIP_STORED, ZIP_DEFLATED, ZIP_BZIP2, ZIP_LZMA
 from tarfile import open as tar_open
 from collections import OrderedDict
 from .gs import GS
-from .kiplot import config_output, get_output_dir, run_output
-from .misc import WRONG_INSTALL, W_EMPTYZIP, WRONG_ARGUMENTS, INTERNAL_ERROR
+from .kiplot import config_output, run_output, get_output_targets
+from .misc import WRONG_INSTALL, W_EMPTYZIP, INTERNAL_ERROR
 from .optionable import Optionable, BaseOptions
 from .registrable import RegOutput
 from .macros import macros, document, output_class  # noqa: F401
@@ -41,9 +41,13 @@ class FilesList(Optionable):
             self.source = '*'
             """ *File names to add, wildcards allowed. Use ** for recursive match.
                 By default this pattern is applied to the output dir specified with `-d` command line option.
-                See the `from_cwd` option """
+                See the `from_cwd` and `from_output_dir` options """
             self.from_cwd = False
             """ Use the current working directory instead of the dir specified by `-d` """
+            self.from_output_dir = False
+            """ Use the current directory specified by the output instead of the dir specified by `-d`.
+                Note that it only applies when using `from_output` and no `dest` is specified.
+                It has more prescedence than `from_cwd` """
             self.from_output = ''
             """ *Collect files from the selected output.
                 When used the `source` option is ignored """
@@ -146,30 +150,35 @@ class CompressOptions(BaseOptions):
         for f in self.files:
             # Get the list of candidates
             files_list = None
+            output_out_dir = None
             if f.from_output:
                 logger.debugl(2, '- From output `{}`'.format(f.from_output))
-                out = RegOutput.get_output(f.from_output)
-                if out is not None:
-                    config_output(out)
-                    out_dir = get_output_dir(out.dir, out, dry=True)
-                    files_list = out.get_targets(out_dir)
-                    logger.debugl(2, '- List of files: {}'.format(files_list))
-                    if out_dir not in dirs_list:
-                        dirs_list.append(out_dir)
-                else:
-                    logger.error('Unknown output `{}` selected in {}'.format(f.from_output, self._parent))
-                    exit(WRONG_ARGUMENTS)
+                files_list, out_dir, out = get_output_targets(f.from_output, self._parent)
+                output_out_dir = out_dir
+                logger.debugl(2, '- List of files: {}'.format(files_list))
+                if out_dir not in dirs_list:
+                    dirs_list.append(out_dir)
                 if not no_out_run:
+                    extra_files = []
                     for file in files_list:
-                        if not os.path.isfile(file):
+                        if not os.path.exists(file):
                             # The target doesn't exist
                             if not out._done:
                                 # The output wasn't created in this run, try running it
                                 run_output(out)
-                            if not os.path.isfile(file):
+                            if not os.path.exists(file):
                                 # Still missing, something is wrong
                                 logger.error('Unable to generate `{}` from {}'.format(file, out))
                                 exit(INTERNAL_ERROR)
+                        if os.path.isdir(file):
+                            # Popultate output adds the image dirs
+                            # Computing its content is complex:
+                            # - We must parse the input markdown
+                            # - We must coinfigure and use the renderer output to do the file name expansion
+                            # This is almost as complex as generating the whole output, so it adds the dir
+                            extra_files = glob.iglob(os.path.join(file, '**'))
+                    if extra_files:
+                        files_list += extra_files
             else:
                 out_dir = out_dir_cwd if f.from_cwd else out_dir_default
                 source = f.expand_filename_both(f.source, make_safe=False)
@@ -177,6 +186,10 @@ class CompressOptions(BaseOptions):
                 if GS.debug_level > 1:
                     files_list = list(files_list)
                     logger.debug('- Pattern {} list of files: {}'.format(source, files_list))
+            # Compute the reference dir when no f.dest
+            out_dir = out_dir_cwd if f.from_cwd else out_dir_default
+            if f.from_output_dir:
+                out_dir = output_out_dir
             # Filter and adapt them
             for fname in filter(re.compile(f.filter).match, files_list):
                 fname_real = os.path.realpath(fname) if self.follow_links else os.path.abspath(fname)
@@ -188,7 +201,6 @@ class CompressOptions(BaseOptions):
                 if f.dest:
                     dest = os.path.join(f.dest, os.path.basename(fname))
                 else:
-                    out_dir = out_dir_cwd if f.from_cwd else out_dir_default
                     dest = os.path.relpath(dest, out_dir)
                 files[fname_real] = dest
         return files, dirs_list
