@@ -1,29 +1,44 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2021-2022 Salvador E. Tropea
-# Copyright (c) 2021-2022 Instituto Nacional de Tecnología Industrial
+# Copyright (c) 2021-2023 Salvador E. Tropea
+# Copyright (c) 2021-2023 Instituto Nacional de Tecnología Industrial
 # License: GPL-3.0
 # Project: KiBot (formerly KiPlot)
-# KiCad 6 bug: https://gitlab.com/kicad/code/kicad/-/issues/9890
+# KiCad 6/6.0.1 bug: https://gitlab.com/kicad/code/kicad/-/issues/9890
 """
 Dependencies:
   - from: KiAuto
     role: mandatory
     version: 2.0.4
+  - from: ImageMagick
+    role: Automatically crop images
 """
 import os
-from shutil import rmtree
+import shlex
+import subprocess
 from .misc import (RENDER_3D_ERR, PCB_MAT_COLORS, PCB_FINISH_COLORS, SOLDER_COLORS, SILK_COLORS,
                    KICAD_VERSION_6_0_2, MISSING_TOOL)
 from .gs import GS
-from .kiplot import exec_with_retry, add_extra_options
-from .out_base_3d import Base3DOptions, Base3D
+from .out_base_3d import Base3DOptionsWithHL, Base3D
 from .macros import macros, document, output_class  # noqa: F401
 from . import log
 
 logger = log.get_logger()
 
 
-class Render3DOptions(Base3DOptions):
+def _run_command(cmd):
+    logger.debug('- Executing: '+shlex.join(cmd))
+    try:
+        cmd_output = subprocess.check_output(cmd, stderr=subprocess.STDOUT)
+    except subprocess.CalledProcessError as e:
+        logger.error('Failed to run %s, error %d', cmd[0], e.returncode)
+        if e.output:
+            logger.debug('Output from command: '+e.output.decode())
+        exit(RENDER_3D_ERR)
+    if cmd_output.strip():
+        logger.debug('- Output from command:\n'+cmd_output.decode())
+
+
+class Render3DOptions(Base3DOptionsWithHL):
     _colors = {'background1': 'bg_color_1',
                'background2': 'bg_color_2',
                'copper': 'copper_color',
@@ -103,6 +118,16 @@ class Render3DOptions(Base3DOptions):
             """ Clip silkscreen at via annuli (KiCad 6) """
             self.subtract_mask_from_silk = True
             """ Clip silkscreen at solder mask edges (KiCad 6) """
+            self.auto_crop = False
+            """ When enabled the image will be post-processed to remove the empty space around the image.
+                In this mode the `background2` is changed to be the same as `background1` """
+            self.transparent_background = False
+            """ When enabled the image will be post-processed to make the background transparent.
+                In this mode the `background1` and `background2` colors are ignored """
+            self.transparent_background_color = "#00ff00"
+            """ Color used for the chroma key. Adjust it if some regions of the board becomes transparent """
+            self.transparent_background_fuzz = 15
+            """ [0,100] Chroma key tolerance (percent). Bigger values will remove more pixels """
         super().__init__()
         self._expand_ext = 'png'
 
@@ -142,13 +167,35 @@ class Render3DOptions(Base3DOptions):
                 if nm in name:
                     self.copper = "#"+color
                     break
+        # Now we can configure (defaults applied)
         super().config(parent)
-        self.validate_colors(self._colors.keys())
+        self.validate_colors(list(self._colors.keys())+['transparent_background_color'])
+        # View and also add it to the ID
         view = self._views.get(self.view, None)
         if view is not None:
             self.view = view
         self._expand_id += '_'+self._rviews.get(self.view)
 
+    def setup_renderer(self, components, active_components, bottom, name):
+        super().setup_renderer(components, active_components)
+        self.view = 'Z' if bottom else 'z'
+        self.output = name
+        return self.expand_filename_both(name, is_sch=False)
+
+    def save_renderer_options(self):
+        """ Save the current renderer settings """
+        super().save_renderer_options()
+        self.old_show_all_components = self._show_all_components
+        self.old_view = self.view
+        self.old_output = self.output
+
+    def restore_renderer_options(self):
+        """ Restore the renderer settings """
+        super().restore_renderer_options()
+        self._show_all_components = self.old_show_all_components
+        self.view = self.old_view
+        self.output = self.old_output
+
     def add_step(self, cmd, steps, ops):
         if steps:
             cmd.extend([ops, str(steps)])
@@ -201,28 +248,30 @@ class Render3DOptions(Base3DOptions):
                          "Please upgrade KiCad to 6.0.2 or newer")
             exit(MISSING_TOOL)
         command = self.ensure_tool('KiAuto')
+        if self.transparent_background:
+            # Use the chroma key color
+            self.background1 = self.background2 = self.transparent_background_color
+            convert_command = self.ensure_tool('ImageMagick')
+        elif self.auto_crop:
+            # Avoid a gradient
+            self.background2 = self.background1
+            convert_command = self.ensure_tool('ImageMagick')
         # Base command with overwrite
         cmd = [command, '--rec_w', str(self.width+2), '--rec_h', str(self.height+85),
                '3d_view', '--output_name', output]
         self.add_options(cmd)
         # The board
-        board_name = self.filter_components()
+        self.apply_show_components()
+        board_name = self.filter_components(highlight=set(self.expand_kf_components(self.highlight)))
+        self.undo_show_components()
         cmd.extend([board_name, os.path.dirname(output)])
-        cmd, video_remove = add_extra_options(cmd)
         # Execute it
-        ret = exec_with_retry(cmd)
-        # Remove the temporal PCB
-        self.remove_tmp_board(board_name)
-        # Remove the downloaded 3D models
-        if self._tmp_dir:
-            rmtree(self._tmp_dir)
-        if ret:
-            logger.error(command+' returned %d', ret)
-            exit(RENDER_3D_ERR)
-        if video_remove:
-            video_name = os.path.join(self.expand_filename_pcb(GS.out_dir), 'pcbnew_3d_view_screencast.ogv')
-            if os.path.isfile(video_name):
-                os.remove(video_name)
+        self.exec_with_retry(self.add_extra_options(cmd), RENDER_3D_ERR)
+        if self.auto_crop:
+            _run_command([convert_command, output, '-trim', '+repage', '-trim', '+repage', output])
+        if self.transparent_background:
+            _run_command([convert_command, output, '-fuzz', str(self.transparent_background_fuzz)+'%', '-transparent',
+                          self.color_str_to_rgb(self.transparent_background_color), output])
 
 
 @output_class
@@ -236,6 +285,10 @@ class Render_3D(Base3D):  # noqa: F821
             """ *[dict] Options for the `render_3d` output """
         self._category = 'PCB/3D'
 
+    def get_renderer_options(self):
+        """ Where are the options for this output when used as a 'renderer' """
+        return self.options
+
     @staticmethod
     def get_conf_examples(name, layers, templates):
         outs = []
